
.. _matlabplots:


***************************************
Plotting using Matlab
***************************************

Up through Version 4.3, we have always used Matlab for plotting and an
extensive set of plotting tools have been developed.  These are still
available in the matlab subdirctory of the Clawpack 4.4 distribution,
`$CLAW/matlab <claw/matlab>`_
These are essentially unchanged from 4.3.

Starting in 4.4, we have also introduced a set of Python plotting tools, see
:ref:`plotting` for some of the advantages of switching to these tools.

For documentation of the Matlab plotting tools, see the :ref:`claw43`.

.. warning:: There is one change to the form of the output files `fort.000N` starting in
   Clawpack 4.4:  The parameter `ndim` has been added.  
